summaryrefslogtreecommitdiff
path: root/tools
diff options
context:
space:
mode:
Diffstat (limited to 'tools')
-rwxr-xr-xtools/checkAPIs.pl4
1 files changed, 2 insertions, 2 deletions
diff --git a/tools/checkAPIs.pl b/tools/checkAPIs.pl
index e83bbfd6ad..6c9a0438f1 100755
--- a/tools/checkAPIs.pl
+++ b/tools/checkAPIs.pl
@@ -1016,7 +1016,7 @@ while ($_ = $ARGV[0])
$errorCount++;
}
# Brute force check for value_string arrays which are not NULL terminated
if ($check_value_string_array_null_termination) {
# Assumption: definition is of form (pseudo-Regex):
# " (static const|static|const) value_string .+ = { .+ ;" (possibly over multiple lines)
@@ -1034,7 +1034,7 @@ while ($_ = $ARGV[0])
# However: since this usage is present in some number of cases, we'll allow for now
if ($vs !~ / , NULL [}] ,? [}] ; $/xo) {
$vsx =~ /( value_string [^=]+ ) = /xo;
- printf STDERR "Error: %-35.35s: Not terminated: %s\n", $filename, $1;
+ printf STDERR "Error: %-35.35s: {0, NULL} is required as the last value_string array entry: %s\n", $filename, $1;
$errorCount++;
}
if ($vs !~ / (static)? const value_string /xo) {
@@ -1016,7 +1016,7 @@ while ($_ = $ARGV[0])
$errorCount++;
}
- # Brute force check for value_string arrays which are not NULL terminated
+ # Brute force check for value_string arrays which are missing {0, NULL} as the final (terminating) array entry
if ($check_value_string_array_null_termination) {
# Assumption: definition is of form (pseudo-Regex):